const is = require('electron-is')
const download = require('download')
const fs = require('fs')
const fsExtra = require('fs-extra')

const pkgJson = require('./package')

async function doDownload(url, dest) {
  console.log('do download ', url)
  let success = false
  let i = 0
  while (i < 5 && success === false) {
    i++
    try {
      await download(url, dest)
      await new Promise(resolve => setTimeout(resolve, 2000))
      success = true
      console.log(`download ${url} success ${i}`)
    } catch (e) {
      console.log(`download ${url} error ${i} `, e)
    }
  }
}

async function task() {
  const debug = process.argv[2] === 'true' // node install.js true 触发 debug 模式

  const moduleName = 'dby-node-sdl-speaker' // fixme
  const nodeFileName = 'sdl-speaker.node' // fixme

  const platform = is.macOS() ? 'mac' : 'win'
  let electronPkgJson = {
    version: '2',
  }
  if (debug === false) {
    electronPkgJson = require('../electron/package')
  }
  const electronMainVersion = `${electronPkgJson.version.match(/.*?(\d+).*/)[1]}.x`
  const downloadUrlPrefix = `https://paas-electron-sdk.duobeiyun.com/sdk/${platform}/${electronMainVersion}`

  // 校验 version 文件是否合法
  const versionLogPath = './install-version.log'
  let versionFileContent = ''
  let isVersionLogFileCorrect = false
  if (fs.existsSync(versionLogPath)) {
    versionFileContent = fs.readFileSync(versionLogPath).toString('utf8').trim()
    isVersionLogFileCorrect = versionFileContent === pkgJson.version
  }

  // download .node file
  if (isVersionLogFileCorrect === false || fs.existsSync(`./build/Release/${nodeFileName}`) === false) {
    const url = `${downloadUrlPrefix}/${moduleName}/${pkgJson.version}/${nodeFileName}`
    await doDownload(url, './build/Release')
  }

  // 最后一步存一下当前的版本号
  fsExtra.ensureFileSync(versionLogPath)
  fs.writeFileSync(versionLogPath, `${pkgJson.version}`)
}

console.log('process.env.npm_config_env_local ', process.env.npm_config_env_local)
if (process.env.npm_config_env_local !== 'true') {
  task().catch((e) => {
    console.log(e)
    process.exit(-1)
  })
}
